package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.common.core.domain.entity.ImageDatas;

/**
 * 附件信息Service接口
 * 
 * @author boman
 * @date 2021-12-24
 */
public interface IImageDataService 
{
    /**
     * 查询附件信息
     * 
     * @param imageId 附件信息主键
     * @return 附件信息
     */
    public ImageDatas selectImageDataByImageId(Long imageId);

    /**
     * 查询附件信息列表
     * 
     * @param imageData 附件信息
     * @return 附件信息集合
     */
    public List<ImageDatas> selectImageDatasList(ImageDatas imageData);

    /**
     * 门户查询附件信息列表
     * @param imageData
     * @return
     */
    public List<ImageDatas> selectImageDatasListMenHu(ImageDatas imageData);

    /**
     * 新增附件信息
     * 
     * @param imageData 附件信息
     * @return 结果
     */
    public int insertImageData(ImageDatas imageData);

    /**
     * 修改附件信息
     * 
     * @param imageData 附件信息
     * @return 结果
     */
    public int updateImageData(ImageDatas imageData);

    /**
     * 批量删除附件信息
     * 
     * @param imageIds 需要删除的附件信息主键集合
     * @return 结果
     */
    public int deleteImageDataByImageIds(Long[] imageIds);

    /**
     * 删除附件信息信息
     * 
     * @param imageId 附件信息主键
     * @return 结果
     */
    public int deleteImageDataByImageId(Long imageId);
}
